toString method
Returns the string representation of this path according to SVG’s path data specification.
path.toString() // "M40,0A40,40,0,1,1,-40,0A40,40,0,1,1,40,0"
Implementation
@override
String toString() {
return _;
}
Returns the string representation of this path according to SVG’s path data specification.
path.toString() // "M40,0A40,40,0,1,1,-40,0A40,40,0,1,1,40,0"
@override
String toString() {
return _;
}