quantiles property

List<num> get quantiles

Returns the quantile thresholds.

color.quantiles // [3475, 3800, 4300, 4950]

If the range contains n discrete values, the returned list will contain n - 1 thresholds. Values less than the first threshold are considered in the first quantile; values greater than or equal to the first threshold but less than the second threshold are in the second quantile, and so on. Internally, the thresholds array is used with bisect (see bisectRight) to find the output quantile associated with the given input value.

Implementation

List<num> get quantiles => _thresholds.sublist(0);