offset property

void Function(List<List<List<num>>>, List<int>) get offset

Given the generated series list and the order index list, it is then responsible for updating the lower and upper values in the series list.

final stack = Stack(…)..offset = stackOffsetExpand;

stack.offset; // stackOffsetExpand

See the built-in offsets for a reference implementation.

The offset accessor defaults to stackOffsetNone; this uses a zero baseline. See stack offsets for the built-in offsets.

Implementation

void Function(List<List<List<num>>>, List<int>) get offset => _offset;
set offset (void offset(List<List<List<num>>>, List<int>)?)

Implementation

set offset(void Function(List<List<List<num>>>, List<int>)? offset) {
  _offset = offset ?? stackOffsetNone;
}