TimeFormatLocale class

Time locale formats define how a date should be parsed and formatted in a locale-specific way.

Constructors

TimeFormatLocale({required String dateTime, required String date, required String time, required List<String> periods, required List<String> days, required List<String> shortDays, required List<String> months, required List<String> shortMonths})
Returns a locale object for the specified definition with format and parse methods.
TimeFormatLocale.fromJson(Map<String, dynamic> definition)
Equivalent to TimeFormatLocale.new, but it accepts a JSON definition object instead of individual arguments
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

format(String specifier) String Function(DateTime)
Returns a new formatter for the given string specifier.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String specifier, {bool isUtc = false}) DateTime? Function(String)
Returns a new parser for the given string specifier.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited