geoParseObject function

Map<String?, dynamic> geoParseObject(
  1. Object object
)

Returns a deep copy of the GeoJSON object with the most precise types for the structure by traversing and rebuilding on the way back.

Implementation

Map<String?, dynamic> geoParseObject(Object object) =>
    _jsonGeoObjectType(JsonReader.fromObject(object));