tickIncrement function

num tickIncrement(
  1. num start,
  2. num stop,
  3. num count
)

Like tickStep, except requires that start is always less than or equal to stop, and if the tick step for the given start, stop and count would be less than one, returns the negative inverse tick step instead.

This method is always guaranteed to return an integer, and is used by ticks to guarantee that the returned tick values are represented as precisely as possible in IEEE 754 floating point.

Implementation

num tickIncrement(num start, num stop, num count) {
  return _tickSpec(start, stop, count).$3;
}