call method
Returns a new list [x, y] (typically in pixels) representing the
projected point of the given point.
The point must be specified as a two-element list
[longitude, latitude] in degrees. May return a two-element list
filled with double.nan if the specified point has no defined projected
position, such as when the point is outside the clipping bounds of the
projection.
Implementation
List<num>? call(List<num> point) =>
_projectRotateTransform.$1(point[0] * radians, point[1] * radians);