fitHeight method
A convenience method for fitSize where the width is automatically chosen from the aspect ratio of object and the given constraint on height.
Implementation
void fitHeight(double height, Map object) {
fit.height(this, height, object);
}